@@ -57,6 +57,19 @@ class Acuse(BaseModel):
     class Config:  # noqa: WPS306, WPS431
         use_enum_values = True
 
+    @classmethod
+    def parse_synchronous_xml(cls, mensaje_element):
+        acuse_element = mensaje_element.find('{http://www.praxis.com.mx/EnvioCda/}acuseCda')  # noqa: E501
+        cda_data = cls._find_mensaje_attributes(mensaje_element, acuse_element)
+        resultado_element = acuse_element.find('{http://www.praxis.com.mx/EnvioCda/}resultadoEnlaceCep')  # noqa: E501
+        codigo = resultado_element.find('{http://www.praxis.com.mx/EnvioCda/}codigo')
+        descripcion = resultado_element.find('{http://www.praxis.com.mx/EnvioCda/}descripcion')  # noqa: E501
+        enlace_cep_data = {
+            'codigo': codigo.text,
+            'descripcion': descripcion.text,
+        }
+        return cls._build_acuse(acuse_element, cda_data, enlace_cep_data)
+
     def build_xml(self):
         acuse = etree.Element(
             'acuse',
@@ -122,9 +135,10 @@ class Acuse(BaseModel):
         }
 
     @classmethod
-    def _build_acuse(cls, acuse_element, cda_data, enlace_cep_data, banxico_data):
+    def _build_acuse(cls, acuse_element, cda_data, enlace_cep_data, banxico_data=None):
         for element in acuse_element.getchildren():
-            tag = to_snake_case(element.tag)
+            localname = etree.QName(element).localname
+            tag = to_snake_case(localname)
             if tag == 'resultado_enlace_cep':
                 cda_data[tag] = ResultadoServidor(**enlace_cep_data)
                 continue
